@@ -77,9 +77,8 @@ def showable_cell_value(celltype, cellvalue, datemode):
     if celltype == xlrd.XL_CELL_DATE:
         try:
             showval = xlrd.xldate_as_tuple(cellvalue, datemode)
-        except xlrd.XLDateError:
-            e1, e2 = sys.exc_info()[:2]
-            showval = "%s:%s" % (e1.__name__, e2)
+        except xlrd.XLDateError as e:
+            showval = "%s:%s" % (type(e).__name__, e)
     elif celltype == xlrd.XL_CELL_ERROR:
         showval = xlrd.error_text_from_code.get(
             cellvalue, '<Unknown error code 0x%02x>' % cellvalue)
@@ -88,7 +87,7 @@ def showable_cell_value(celltype, cellvalue, datemode):
     return showval
 
 def show_name_object(book, nobj, show_contents=0, f=sys.stdout):
-    print("\nName: %s, scope: %s (%s)" \
+    print("\nName: %s, scope: %s (%s)"
         % (REPR(nobj.name), REPR(nobj.scope), scope_as_string(book, nobj.scope)), file=f)
     res = nobj.result
     print("Formula eval result: %s" % REPR(res), file=f)
@@ -155,7 +154,7 @@ Examples (script name and glob_pattern arg omitted for brevity)
 
 """
         sys.stdout.write(text)
-    
+
     if len(sys.argv) != 5:
         usage()
         sys.exit(0)
