@@ -1,36 +1,22 @@
 # -*- coding: cp1252 -*-
-
-##
-# Module for formatting information.
-#
-# <p>Copyright  2005-2012 Stephen John Machin, Lingfo Pty Ltd</p>
-# <p>This module is part of the xlrd package, which is released under
-# a BSD-style licence.</p>
-##
-
-# No part of the content of this file was derived from the works of David Giffin.
-
-# 2010-10-30 SJM Added space after colon in "# coding" line to work around IBM iSeries Python bug
-# 2009-05-31 SJM Fixed problem with non-zero reserved bits in some STYLE records in Mac Excel files
-# 2008-08-03 SJM Ignore PALETTE record when Book.formatting_info is false
-# 2008-08-03 SJM Tolerate up to 4 bytes trailing junk on PALETTE record
-# 2008-05-10 SJM Do some XF checks only when Book.formatting_info is true
-# 2008-02-08 SJM Preparation for Excel 2.0 support
-# 2008-02-03 SJM Another tweak to is_date_format_string()
-# 2007-12-04 SJM Added support for Excel 2.x (BIFF2) files.
-# 2007-10-13 SJM Warning: style XF whose parent XF index != 0xFFF
-# 2007-09-08 SJM Work around corrupt STYLE record
-# 2007-07-11 SJM Allow for BIFF2/3-style FORMAT record in BIFF4/8 file
+# Copyright (c) 2005-2012 Stephen John Machin, Lingfo Pty Ltd
+# This module is part of the xlrd package, which is released under a
+# BSD-style licence.
+# No part of the content of this file was derived from the works of
+# David Giffin.
+"""
+Module for formatting information.
+"""
 
 from __future__ import print_function
 
 DEBUG = 0
-import copy, re
+import re
 from struct import unpack
 from .timemachine import *
 from .biffh import BaseObject, unpack_unicode, unpack_string, \
     upkbits, upkbitsL, fprintf, \
-    FUN, FDT, FNU, FGE, FTX, XL_CELL_NUMBER, XL_CELL_DATE, \
+    FUN, FDT, FNU, FGE, FTX, XL_CELL_NUMBER, XL_CELL_DATE, XL_CELL_TEXT, \
     XL_FORMAT, XL_FORMAT2, \
     XLRDError
 
@@ -40,8 +26,8 @@ _cellty_from_fmtty = {
     FGE: XL_CELL_NUMBER,
     FDT: XL_CELL_DATE,
     FTX: XL_CELL_NUMBER, # Yes, a number can be formatted as text.
-    }    
-    
+    }
+
 excel_default_palette_b5 = (
     (  0,   0,   0), (255, 255, 255), (255,   0,   0), (  0, 255,   0),
     (  0,   0, 255), (255, 255,   0), (255,   0, 255), (  0, 255, 255),
@@ -91,18 +77,16 @@ default_palette = {
     20: excel_default_palette_b2,
     }
 
-"""
-00H = Normal
-01H = RowLevel_lv (see next field)
-02H = ColLevel_lv (see next field)
-03H = Comma
-04H = Currency
-05H = Percent
-06H = Comma [0] (BIFF4-BIFF8)
-07H = Currency [0] (BIFF4-BIFF8)
-08H = Hyperlink (BIFF8)
-09H = Followed Hyperlink (BIFF8)
-"""
+# 00H = Normal
+# 01H = RowLevel_lv (see next field)
+# 02H = ColLevel_lv (see next field)
+# 03H = Comma
+# 04H = Currency
+# 05H = Percent
+# 06H = Comma [0] (BIFF4-BIFF8)
+# 07H = Currency [0] (BIFF4-BIFF8)
+# 08H = Hyperlink (BIFF8)
+# 09H = Followed Hyperlink (BIFF8)
 built_in_style_names = [
     "Normal",
     "RowLevel_",
@@ -141,10 +125,12 @@ def initialise_colour_map(book):
         book.colour_map[ci] = None
 
 def nearest_colour_index(colour_map, rgb, debug=0):
-    # General purpose function. Uses Euclidean distance.
-    # So far used only for pre-BIFF8 WINDOW2 record.
-    # Doesn't have to be fast.
-    # Doesn't have to be fancy.
+    """
+    General purpose function. Uses Euclidean distance.
+    So far used only for pre-BIFF8 ``WINDOW2`` record.
+    Doesn't have to be fast.
+    Doesn't have to be fancy.
+    """
     best_metric = 3 * 256 * 256
     best_colourx = 0
     for colourx, cand_rgb in colour_map.items():
@@ -159,14 +145,15 @@ def nearest_colour_index(colour_map, rgb, debug=0):
             if metric == 0:
                 break
     if 0 and debug:
-        print("nearest_colour_index for %r is %r -> %r; best_metric is %d" \
+        print("nearest_colour_index for %r is %r -> %r; best_metric is %d"
             % (rgb, best_colourx, colour_map[best_colourx], best_metric))
     return best_colourx
 
-##
-# This mixin class exists solely so that Format, Font, and XF.... objects
-# can be compared by value of their attributes.
 class EqNeAttrs(object):
+    """
+    This mixin class exists solely so that :class:`Format`, :class:`Font`, and
+    :class:`XF` objects can be compared by value of their attributes.
+    """
 
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
@@ -174,85 +161,93 @@ class EqNeAttrs(object):
     def __ne__(self, other):
         return self.__dict__ != other.__dict__
 
-##
-# An Excel "font" contains the details of not only what is normally
-# considered a font, but also several other display attributes.
-# Items correspond to those in the Excel UI's Format/Cells/Font tab.
-# <br /> -- New in version 0.6.1
 class Font(BaseObject, EqNeAttrs):
-    ##
-    # 1 = Characters are bold. Redundant; see "weight" attribute.
-    bold = 0
-    ##
-    # Values: 0 = ANSI Latin, 1 = System default, 2 = Symbol,
-    # 77 = Apple Roman,
-    # 128 = ANSI Japanese Shift-JIS,
-    # 129 = ANSI Korean (Hangul),
-    # 130 = ANSI Korean (Johab),
-    # 134 = ANSI Chinese Simplified GBK,
-    # 136 = ANSI Chinese Traditional BIG5,
-    # 161 = ANSI Greek,
-    # 162 = ANSI Turkish,
-    # 163 = ANSI Vietnamese,
-    # 177 = ANSI Hebrew,
-    # 178 = ANSI Arabic,
-    # 186 = ANSI Baltic,
-    # 204 = ANSI Cyrillic,
-    # 222 = ANSI Thai,
-    # 238 = ANSI Latin II (Central European),
-    # 255 = OEM Latin I
-    character_set = 0
-    ##
-    # An explanation of "colour index" is given in the Formatting
-    # section at the start of this document.
-    colour_index = 0
-    ##
-    # 1 = Superscript, 2 = Subscript.
-    escapement = 0
-    ##
-    # 0 = None (unknown or don't care)<br />
-    # 1 = Roman (variable width, serifed)<br />
-    # 2 = Swiss (variable width, sans-serifed)<br />
-    # 3 = Modern (fixed width, serifed or sans-serifed)<br />
-    # 4 = Script (cursive)<br />
-    # 5 = Decorative (specialised, for example Old English, Fraktur)
-    family = 0
-    ##
-    # The 0-based index used to refer to this Font() instance.
-    # Note that index 4 is never used; xlrd supplies a dummy place-holder.
-    font_index = 0
-    ##
-    # Height of the font (in twips). A twip = 1/20 of a point.
-    height = 0
-    ##
-    # 1 = Characters are italic.
-    italic = 0
-    ##
-    # The name of the font. Example: u"Arial"
-    name = UNICODE_LITERAL("")
-    ##
-    # 1 = Characters are struck out.
-    struck_out = 0
-    ##
-    # 0 = None<br />
-    # 1 = Single;  0x21 (33) = Single accounting<br />
-    # 2 = Double;  0x22 (34) = Double accounting
-    underline_type = 0
-    ##
-    # 1 = Characters are underlined. Redundant; see "underline_type" attribute.
-    underlined = 0
-    ##
-    # Font weight (100-1000). Standard values are 400 for normal text
-    # and 700 for bold text.
-    weight = 400
-    ##
-    # 1 = Font is outline style (Macintosh only)
-    outline = 0
-    ##
-    # 1 = Font is shadow style (Macintosh only)
-    shadow = 0
+    """
+    An Excel "font" contains the details of not only what is normally
+    considered a font, but also several other display attributes.
+    Items correspond to those in the Excel UI's Format -> Cells -> Font tab.
 
-    # No methods ...
+    .. versionadded:: 0.6.1
+    """
+
+    #: 1 = Characters are bold. Redundant; see "weight" attribute.
+    bold = 0
+
+    #: Values::
+    #:
+    #:   0 = ANSI Latin
+    #:   1 = System default
+    #:   2 = Symbol,
+    #:   77 = Apple Roman,
+    #:   128 = ANSI Japanese Shift-JIS,
+    #:   129 = ANSI Korean (Hangul),
+    #:   130 = ANSI Korean (Johab),
+    #:   134 = ANSI Chinese Simplified GBK,
+    #:   136 = ANSI Chinese Traditional BIG5,
+    #:   161 = ANSI Greek,
+    #:   162 = ANSI Turkish,
+    #:   163 = ANSI Vietnamese,
+    #:   177 = ANSI Hebrew,
+    #:   178 = ANSI Arabic,
+    #:   186 = ANSI Baltic,
+    #:   204 = ANSI Cyrillic,
+    #:   222 = ANSI Thai,
+    #:   238 = ANSI Latin II (Central European),
+    #:   255 = OEM Latin I
+    character_set = 0
+
+    #: An explanation of "colour index" is given in :ref:`palette`.
+    colour_index = 0
+
+    #: 1 = Superscript, 2 = Subscript.
+    escapement = 0
+
+    #: Values::
+    #:
+    #:   0 = None (unknown or don't care)
+    #:   1 = Roman (variable width, serifed)
+    #:   2 = Swiss (variable width, sans-serifed)
+    #:   3 = Modern (fixed width, serifed or sans-serifed)
+    #:   4 = Script (cursive)
+    #:   5 = Decorative (specialised, for example Old English, Fraktur)
+    family = 0
+
+    #: The 0-based index used to refer to this Font() instance.
+    #: Note that index 4 is never used; xlrd supplies a dummy place-holder.
+    font_index = 0
+
+    #: Height of the font (in twips). A twip = 1/20 of a point.
+    height = 0
+
+    #: 1 = Characters are italic.
+    italic = 0
+
+    #: The name of the font. Example: ``u"Arial"``.
+    name = UNICODE_LITERAL("")
+
+    #: 1 = Characters are struck out.
+    struck_out = 0
+
+    #: Values::
+    #:
+    #:   0 = None
+    #:   1 = Single;  0x21 (33) = Single accounting
+    #:   2 = Double;  0x22 (34) = Double accounting
+    underline_type = 0
+
+    #: 1 = Characters are underlined. Redundant; see
+    #: :attr:`underline_type` attribute.
+    underlined = 0
+
+    #: Font weight (100-1000). Standard values are 400 for normal text
+    #: and 700 for bold text.
+    weight = 400
+
+    #: 1 = Font is outline style (Macintosh only)
+    outline = 0
+
+    #: 1 = Font is shadow style (Macintosh only)
+    shadow = 0
 
 def handle_efont(book, data): # BIFF2 only
     if not book.formatting_info:
@@ -279,7 +274,7 @@ def handle_font(book, data):
     if bv >= 50:
         (
             f.height, option_flags, f.colour_index, f.weight,
-            f.escapement_type, f.underline_type, f.family,
+            f.escapement, f.underline_type, f.family,
             f.character_set,
         ) = unpack('<HHHHHBBB', data[0:13])
         f.bold = option_flags & 1
@@ -303,7 +298,7 @@ def handle_font(book, data):
         f.name = unpack_string(data, 6, book.encoding, lenlen=1)
         # Now cook up the remaining attributes ...
         f.weight = [400, 700][f.bold]
-        f.escapement_type = 0 # None
+        f.escapement = 0 # None
         f.underline_type = f.underlined # None or Single
         f.family = 0 # Unknown / don't care
         f.character_set = 1 # System default (0 means "ANSI Latin")
@@ -319,7 +314,7 @@ def handle_font(book, data):
         f.name = unpack_string(data, 4, book.encoding, lenlen=1)
         # Now cook up the remaining attributes ...
         f.weight = [400, 700][f.bold]
-        f.escapement_type = 0 # None
+        f.escapement = 0 # None
         f.underline_type = f.underlined # None or Single
         f.family = 0 # Unknown / don't care
         f.character_set = 1 # System default (0 means "ANSI Latin")
@@ -332,25 +327,28 @@ def handle_font(book, data):
 
 # === "Number formats" ===
 
-##
-# "Number format" information from a FORMAT record.
-# <br /> -- New in version 0.6.1
 class Format(BaseObject, EqNeAttrs):
-    ##
-    # The key into Book.format_map
+    """
+    "Number format" information from a ``FORMAT`` record.
+
+    .. versionadded:: 0.6.1
+    """
+
+    #: The key into :attr:`~xlrd.book.Book.format_map`
     format_key = 0
-    ##
-    # A classification that has been inferred from the format string.
-    # Currently, this is used only to distinguish between numbers and dates.
-    # <br />Values:
-    # <br />FUN = 0 # unknown
-    # <br />FDT = 1 # date
-    # <br />FNU = 2 # number
-    # <br />FGE = 3 # general
-    # <br />FTX = 4 # text
+
+    #: A classification that has been inferred from the format string.
+    #: Currently, this is used only to distinguish between numbers and dates.
+    #: Values::
+    #:
+    #:   FUN = 0 # unknown
+    #:   FDT = 1 # date
+    #:   FNU = 2 # number
+    #:   FGE = 3 # general
+    #:   FTX = 4 # text
     type = FUN
-    ##
-    # The format string
+
+    #: The format string
     format_str = UNICODE_LITERAL('')
 
     def __init__(self, format_key, ty, format_str):
@@ -468,7 +466,7 @@ def is_date_format_string(book, fmt):
     # TODO: u'[h]\\ \\h\\o\\u\\r\\s' ([h] means don't care about hours > 23)
     state = 0
     s = ''
-    
+
     for c in fmt:
         if state == 0:
             if c == UNICODE_LITERAL('"'):
@@ -622,7 +620,7 @@ def palette_epilogue(book):
             book.colour_indexes_used[cx] = 1
         elif book.verbosity:
             print("Size of colour table:", len(book.colour_map), file=book.logfile)
-            fprintf(self.logfile, "*** Font #%d (%r): colour index 0x%04x is unknown\n",
+            fprintf(book.logfile, "*** Font #%d (%r): colour index 0x%04x is unknown\n",
                 font.font_index, font.name, cx)
     if book.verbosity >= 1:
         used = sorted(book.colour_indexes_used.keys())
@@ -659,7 +657,7 @@ def handle_style(book, data):
             try:
                 name = unpack_unicode(data, 2, lenlen=2)
             except UnicodeDecodeError:
-                print("STYLE: built_in=%d xf_index=%d built_in_id=%d level=%d" \
+                print("STYLE: built_in=%d xf_index=%d built_in_id=%d level=%d"
                     % (built_in, xf_index, built_in_id, level), file=book.logfile)
                 print("raw bytes:", repr(data[2:]), file=book.logfile)
                 raise
@@ -682,7 +680,7 @@ def check_colour_indexes_in_obj(book, obj, orig_index):
                 book.colour_indexes_used[nobj] = 1
                 continue
             oname = obj.__class__.__name__
-            print("*** xf #%d : %s.%s =  0x%04x (unknown)" \
+            print("*** xf #%d : %s.%s =  0x%04x (unknown)"
                 % (orig_index, oname, attr, nobj), file=book.logfile)
 
 def fill_in_standard_formats(book):
@@ -697,7 +695,7 @@ def fill_in_standard_formats(book):
             book.format_map[x] = fmtobj
 
 def handle_xf(self, data):
-    ### self is a Book instance
+# self is a Book instance
     # DEBUG = 0
     blah = DEBUG or self.verbosity >= 3
     bv = self.biff_version
@@ -907,10 +905,10 @@ def handle_xf(self, data):
         xf.alignment.vert_align = 2 # bottom
         xf.alignment.rotation = 0
     elif bv == 21:
-        #### Warning: incomplete treatment; formatting_info not fully supported.
-        #### Probably need to offset incoming BIFF2 XF[n] to BIFF8-like XF[n+16],
-        #### and create XF[0:16] like the standard ones in BIFF8
-        #### *AND* add 16 to all XF references in cell records :-(
+    ## Warning: incomplete treatment; formatting_info not fully supported.
+    ## Probably need to offset incoming BIFF2 XF[n] to BIFF8-like XF[n+16],
+    ## and create XF[0:16] like the standard ones in BIFF8
+    ## *AND* add 16 to all XF references in cell records :-(
         (xf.font_index, format_etc, halign_etc) = unpack('<BxBB', data)
         xf.format_key = format_etc & 0x3F
         upkbits(xf.protection, format_etc, (
@@ -991,14 +989,12 @@ def xf_epilogue(self):
 
     for xfx in xrange(num_xfs):
         xf = self.xf_list[xfx]
-        if xf.format_key not in self.format_map:
-            msg = "ERROR *** XF[%d] unknown format key (%d, 0x%04x)\n"
-            fprintf(self.logfile, msg,
-                    xf.xf_index, xf.format_key, xf.format_key)
-            xf.format_key = 0
 
-        fmt = self.format_map[xf.format_key]
-        cellty = _cellty_from_fmtty[fmt.type]
+        try:
+            fmt = self.format_map[xf.format_key]
+            cellty = _cellty_from_fmtty[fmt.type]
+        except KeyError:
+            cellty = XL_CELL_TEXT
         self._xf_index_to_xl_type_map[xf.xf_index] = cellty
         # Now for some assertions etc
         if not self.formatting_info:
@@ -1021,7 +1017,7 @@ def xf_epilogue(self):
                 elif not self.xf_list[xf.parent_style_index].is_style:
                     fprintf(self.logfile,
                         "NOTE !!! XF[%d]: parent_style_index is %d; style flag not set\n",
-                        xf.xf_index, xf.parent_style_index)                
+                        xf.xf_index, xf.parent_style_index)
             if blah1 and xf.parent_style_index > xf.xf_index:
                 fprintf(self.logfile,
                     "NOTE !!! XF[%d]: parent_style_index is %d; out of order?\n",
@@ -1065,210 +1061,222 @@ def initialise_book(book):
     for method in methods:
         setattr(book.__class__, method.__name__, method)
 
-##
-# <p>A collection of the border-related attributes of an XF record.
-# Items correspond to those in the Excel UI's Format/Cells/Border tab.</p>
-# <p> An explanations of "colour index" is given in the Formatting
-# section at the start of this document.
-# There are five line style attributes; possible values and the
-# associated meanings are:
-# 0&nbsp;=&nbsp;No line,
-# 1&nbsp;=&nbsp;Thin,
-# 2&nbsp;=&nbsp;Medium,
-# 3&nbsp;=&nbsp;Dashed,
-# 4&nbsp;=&nbsp;Dotted,
-# 5&nbsp;=&nbsp;Thick,
-# 6&nbsp;=&nbsp;Double,
-# 7&nbsp;=&nbsp;Hair,
-# 8&nbsp;=&nbsp;Medium dashed,
-# 9&nbsp;=&nbsp;Thin dash-dotted,
-# 10&nbsp;=&nbsp;Medium dash-dotted,
-# 11&nbsp;=&nbsp;Thin dash-dot-dotted,
-# 12&nbsp;=&nbsp;Medium dash-dot-dotted,
-# 13&nbsp;=&nbsp;Slanted medium dash-dotted.
-# The line styles 8 to 13 appear in BIFF8 files (Excel 97 and later) only.
-# For pictures of the line styles, refer to OOo docs s3.10 (p22)
-# "Line Styles for Cell Borders (BIFF3-BIFF8)".</p>
-# <br /> -- New in version 0.6.1
 class XFBorder(BaseObject, EqNeAttrs):
+    """
+    A collection of the border-related attributes of an ``XF`` record.
+    Items correspond to those in the Excel UI's Format -> Cells -> Border tab.
 
-    ##
-    # The colour index for the cell's top line
+    An explanations of "colour index" is given in :ref:`palette`.
+
+    There are five line style attributes; possible values and the
+    associated meanings are::
+
+      0 = No line,
+      1 = Thin,
+      2 = Medium,
+      3 = Dashed,
+      4 = Dotted,
+      5 = Thick,
+      6 = Double,
+      7 = Hair,
+      8 = Medium dashed,
+      9 = Thin dash-dotted,
+      10 = Medium dash-dotted,
+      11 = Thin dash-dot-dotted,
+      12 = Medium dash-dot-dotted,
+      13 = Slanted medium dash-dotted.
+
+    The line styles 8 to 13 appear in BIFF8 files (Excel 97 and later) only.
+    For pictures of the line styles, refer to OOo docs s3.10 (p22)
+    "Line Styles for Cell Borders (BIFF3-BIFF8)".</p>
+
+    .. versionadded:: 0.6.1
+    """
+
+    #: The colour index for the cell's top line
     top_colour_index = 0
-    ##
-    # The colour index for the cell's bottom line
+    #: The colour index for the cell's bottom line
     bottom_colour_index = 0
-    ##
-    # The colour index for the cell's left line
+
+    #: The colour index for the cell's left line
     left_colour_index = 0
-    ##
-    # The colour index for the cell's right line
+
+    #: The colour index for the cell's right line
     right_colour_index = 0
-    ##
-    # The colour index for the cell's diagonal lines, if any
+
+    #: The colour index for the cell's diagonal lines, if any
     diag_colour_index = 0
-    ##
-    # The line style for the cell's top line
+
+    #: The line style for the cell's top line
     top_line_style = 0
-    ##
-    # The line style for the cell's bottom line
+
+    #: The line style for the cell's bottom line
     bottom_line_style = 0
-    ##
-    # The line style for the cell's left line
+
+    #: The line style for the cell's left line
     left_line_style = 0
-    ##
-    # The line style for the cell's right line
+
+    #: The line style for the cell's right line
     right_line_style = 0
-    ##
-    # The line style for the cell's diagonal lines, if any
+
+    #: The line style for the cell's diagonal lines, if any
     diag_line_style = 0
-    ##
-    # 1 = draw a diagonal from top left to bottom right
+
+    #: 1 = draw a diagonal from top left to bottom right
     diag_down = 0
-    ##
-    # 1 = draw a diagonal from bottom left to top right
+
+    #: 1 = draw a diagonal from bottom left to top right
     diag_up = 0
 
-##
-# A collection of the background-related attributes of an XF record.
-# Items correspond to those in the Excel UI's Format/Cells/Patterns tab.
-# An explanation of "colour index" is given in the Formatting
-# section at the start of this document.
-# <br /> -- New in version 0.6.1
 class XFBackground(BaseObject, EqNeAttrs):
+    """
+    A collection of the background-related attributes of an ``XF`` record.
+    Items correspond to those in the Excel UI's Format -> Cells -> Patterns tab.
 
-    ##
-    # See section 3.11 of the OOo docs.
+    An explanations of "colour index" is given in :ref:`palette`.
+
+    .. versionadded:: 0.6.1
+    """
+
+    #: See section 3.11 of the OOo docs.
     fill_pattern = 0
-    ##
-    # See section 3.11 of the OOo docs.
+
+    #: See section 3.11 of the OOo docs.
     background_colour_index = 0
-    ##
-    # See section 3.11 of the OOo docs.
+
+    #: See section 3.11 of the OOo docs.
     pattern_colour_index = 0
 
-##
-# A collection of the alignment and similar attributes of an XF record.
-# Items correspond to those in the Excel UI's Format/Cells/Alignment tab.
-# <br /> -- New in version 0.6.1
 
 class XFAlignment(BaseObject, EqNeAttrs):
+    """
+    A collection of the alignment and similar attributes of an ``XF`` record.
+    Items correspond to those in the Excel UI's Format -> Cells -> Alignment tab.
 
-    ##
-    # Values: section 6.115 (p 214) of OOo docs
+    .. versionadded:: 0.6.1
+    """
+
+    #: Values: section 6.115 (p 214) of OOo docs
     hor_align = 0
-    ##
-    # Values: section 6.115 (p 215) of OOo docs
+
+    #: Values: section 6.115 (p 215) of OOo docs
     vert_align = 0
-    ##
-    # Values: section 6.115 (p 215) of OOo docs.<br />
-    # Note: file versions BIFF7 and earlier use the documented
-    # "orientation" attribute; this will be mapped (without loss)
-    # into "rotation".
+
+    #: Values: section 6.115 (p 215) of OOo docs.
+    #:
+    #: .. note::
+    #:   file versions BIFF7 and earlier use the documented
+    #:   :attr:`orientation` attribute; this will be mapped (without loss)
+    #:   into :attr:`rotation`.
     rotation = 0
-    ##
-    # 1 = text is wrapped at right margin
+
+    #: 1 = text is wrapped at right margin
     text_wrapped = 0
-    ##
-    # A number in range(15).
+
+    #: A number in ``range(15)``.
     indent_level = 0
-    ##
-    # 1 = shrink font size to fit text into cell.
+
+    #: 1 = shrink font size to fit text into cell.
     shrink_to_fit = 0
-    ##
-    # 0 = according to context; 1 = left-to-right; 2 = right-to-left
+
+    #: 0 = according to context; 1 = left-to-right; 2 = right-to-left
     text_direction = 0
 
-##
-# A collection of the protection-related attributes of an XF record.
-# Items correspond to those in the Excel UI's Format/Cells/Protection tab.
-# Note the OOo docs include the "cell or style" bit
-# in this bundle of attributes.
-# This is incorrect; the bit is used in determining which bundles to use.
-# <br /> -- New in version 0.6.1
-
 class XFProtection(BaseObject, EqNeAttrs):
+    """
+    A collection of the protection-related attributes of an ``XF`` record.
+    Items correspond to those in the Excel UI's Format -> Cells -> Protection tab.
+    Note the OOo docs include the "cell or style" bit in this bundle of
+    attributes. This is incorrect; the bit is used in determining which bundles
+    to use.
 
-    ##
-    # 1 = Cell is prevented from being changed, moved, resized, or deleted
-    # (only if the sheet is protected).
+    .. versionadded:: 0.6.1
+    """
+
+    #: 1 = Cell is prevented from being changed, moved, resized, or deleted
+    #: (only if the sheet is protected).
     cell_locked = 0
-    ##
-    # 1 = Hide formula so that it doesn't appear in the formula bar when
-    # the cell is selected (only if the sheet is protected).
+
+    #: 1 = Hide formula so that it doesn't appear in the formula bar when
+    #: the cell is selected (only if the sheet is protected).
     formula_hidden = 0
 
-##
-# eXtended Formatting information for cells, rows, columns and styles.
-# <br /> -- New in version 0.6.1
-#
-# <p>Each of the 6 flags below describes the validity of
-# a specific group of attributes.
-# <br />
-# In cell XFs, flag==0 means the attributes of the parent style XF are used,
-# (but only if the attributes are valid there); flag==1 means the attributes
-# of this XF are used.<br />
-# In style XFs, flag==0 means the attribute setting is valid; flag==1 means
-# the attribute should be ignored.<br />
-# Note that the API
-# provides both "raw" XFs and "computed" XFs -- in the latter case, cell XFs
-# have had the above inheritance mechanism applied.
-# </p>
-
 class XF(BaseObject):
+    """
+    eXtended Formatting information for cells, rows, columns and styles.
 
-    ##
-    # 0 = cell XF, 1 = style XF
+    Each of the 6 flags below describes the validity of
+    a specific group of attributes.
+
+    In cell XFs:
+
+    - ``flag==0`` means the attributes of the parent style ``XF`` are
+      used, (but only if the attributes are valid there);
+
+    - ``flag==1`` means the attributes of this ``XF`` are used.
+
+    In style XFs:
+
+    - ``flag==0`` means the attribute setting is valid;
+    - ``flag==1`` means the attribute should be ignored.
+
+    .. note::
+      the API provides both "raw" XFs and "computed" XFs. In the latter case,
+      cell XFs have had the above inheritance mechanism applied.
+
+    .. versionadded:: 0.6.1
+    """
+
+    #: 0 = cell XF, 1 = style XF
     is_style = 0
-    ##
-    # cell XF: Index into Book.xf_list
-    # of this XF's style XF<br />
-    # style XF: 0xFFF
+
+    #: cell XF: Index into Book.xf_list of this XF's style XF
+    #:
+    #: style XF: 0xFFF
     parent_style_index = 0
-    ##
+
     #
     _format_flag = 0
-    ##
+
     #
     _font_flag = 0
-    ##
+
     #
     _alignment_flag = 0
-    ##
+
     #
     _border_flag = 0
-    ##
+
     #
     _background_flag = 0
-    ##
-    # &nbsp;
+
     _protection_flag = 0
-    ##
-    # Index into Book.xf_list
+
+    #: Index into :attr:`~xlrd.book.Book.xf_list`
     xf_index = 0
-    ##
-    # Index into Book.font_list
+
+    #: Index into :attr:`~xlrd.book.Book.font_list`
     font_index = 0
-    ##
-    # Key into Book.format_map
-    # <p>
-    # Warning: OOo docs on the XF record call this "Index to FORMAT record".
-    # It is not an index in the Python sense. It is a key to a map.
-    # It is true <i>only</i> for Excel 4.0 and earlier files
-    # that the key into format_map from an XF instance
-    # is the same as the index into format_list, and <i>only</i>
-    # if the index is less than 164.
-    # </p>
+
+    #: Key into :attr:`~xlrd.book.Book.format_map`
+    #:
+    #: .. warning::
+    #:   OOo docs on the XF record call this "Index to FORMAT record".
+    #:   It is not an index in the Python sense. It is a key to a map.
+    #:   It is true *only* for Excel 4.0 and earlier files
+    #:   that the key into format_map from an XF instance
+    #:   is the same as the index into format_list, and *only*
+    #:   if the index is less than 164.
     format_key = 0
-    ##
-    # An instance of an XFProtection object.
+
+    #: An instance of an :class:`XFProtection` object.
     protection = None
-    ##
-    # An instance of an XFBackground object.
+
+    #: An instance of an :class:`XFBackground` object.
     background = None
-    ##
-    # An instance of an XFAlignment object.
+
+    #: An instance of an :class:`XFAlignment` object.
     alignment = None
-    ##
-    # An instance of an XFBorder object.
+
+    #: An instance of an :class:`XFBorder` object.
     border = None
