@@ -7,6 +7,7 @@ from __future__ import print_function, unicode_literals
 
 DEBUG = 0
 
+from os.path import normpath, join
 import sys
 import re
 from .timemachine import *
@@ -27,7 +28,7 @@ def ensure_elementtree_imported(verbosity, logfile):
         return
     if "IronPython" in sys.version:
         import xml.etree.ElementTree as ET
-        #### 2.7.2.1: fails later with 
+        #### 2.7.2.1: fails later with
         #### NotImplementedError: iterparse is not supported on IronPython. (CP #31923)
     else:
         try: import xml.etree.cElementTree as ET
@@ -56,7 +57,7 @@ def ensure_elementtree_imported(verbosity, logfile):
             if item.lower().replace('_', '') == 'version'
             ])
         print(ET.__file__, ET.__name__, etree_version, ET_has_iterparse, file=logfile)
-        
+
 def split_tag(tag):
     pos = tag.rfind('}') + 1
     if pos >= 2:
@@ -75,7 +76,8 @@ for _x in "123456789":
     _UPPERCASE_1_REL_INDEX[_x] = 0
 del _x
 
-def cell_name_to_rowx_colx(cell_name, letter_value=_UPPERCASE_1_REL_INDEX):
+def cell_name_to_rowx_colx(cell_name, letter_value=_UPPERCASE_1_REL_INDEX,
+        allow_no_col=False):
     # Extract column index from cell name
     # A<row number> => 0, Z =>25, AA => 26, XFD => 16383
     colx = 0
@@ -87,9 +89,18 @@ def cell_name_to_rowx_colx(cell_name, letter_value=_UPPERCASE_1_REL_INDEX):
             if lv:
                 colx = colx * 26 + lv
             else: # start of row number; can't be '0'
-                colx = colx - 1
-                assert 0 <= colx < X12_MAX_COLS
-                break
+                if charx == 0:
+                    # there was no col marker
+                    if allow_no_col:
+                        colx = None
+                        break
+                    else:
+                        raise Exception(
+                                'Missing col in cell name %r', cell_name)
+                else:
+                    colx = colx - 1
+                    assert 0 <= colx < X12_MAX_COLS
+                    break
     except KeyError:
         raise Exception('Unexpected character %r in cell name %r' % (c, cell_name))
     rowx = int(cell_name[charx:]) - 1
@@ -306,6 +317,10 @@ class X12Book(X12General):
             fprintf(self.logfile, "props: %r\n", props)
         self.finish_off()
 
+    @staticmethod
+    def convert_filename(name):
+        return name.replace('\\', '/').lower()
+
     def process_rels(self, stream):
         if self.verbosity >= 2:
             fprintf(self.logfile, "\n=== Relationships ===\n")
@@ -313,7 +328,7 @@ class X12Book(X12General):
         r_tag = U_PKGREL + 'Relationship'
         for elem in tree.findall(r_tag):
             rid = elem.get('Id')
-            target = elem.get('Target')
+            target = X12Book.convert_filename(elem.get('Target'))
             reltype = elem.get('Type').split('/')[-1]
             if self.verbosity >= 2:
                 self.dumpout('Id=%r Type=%r Target=%r', rid, reltype, target)
@@ -407,7 +422,7 @@ class X12SST(X12General):
             self.process_stream = self.process_stream_iterparse
         else:
             self.process_stream = self.process_stream_findall
-            
+
     def process_stream_iterparse(self, stream, heading=None):
         if self.verbosity >= 2 and heading is not None:
             fprintf(self.logfile, "\n=== %s ===\n", heading)
@@ -421,7 +436,7 @@ class X12SST(X12General):
                 fprintf(self.logfile, "element #%d\n", elemno)
                 self.dump_elem(elem)
             result = get_text_from_si_or_is(self, elem)
-            sst.append(result)                
+            sst.append(result)
             elem.clear() # destroy all child elements
         if self.verbosity >= 2:
             self.dumpout('Entries in SST: %d', len(sst))
@@ -514,6 +529,8 @@ class X12Sheet(X12General):
         self.rowx = -1 # We may need to count them.
         self.bk = sheet.book
         self.sst = self.bk._sharedstrings
+        self.relid2path = {}
+        self.relid2reltype = {}
         self.merged_cells = sheet.merged_cells
         self.warned_no_cell_name = 0
         self.warned_no_row_num = 0
@@ -536,6 +553,20 @@ class X12Sheet(X12General):
                 self.do_merge_cell(elem)
         self.finish_off()
 
+    def process_rels(self, stream):
+        if self.verbosity >= 2:
+            fprintf(self.logfile, "\n=== Sheet Relationships ===\n")
+        tree = ET.parse(stream)
+        r_tag = U_PKGREL + 'Relationship'
+        for elem in tree.findall(r_tag):
+            rid = elem.get('Id')
+            target = elem.get('Target')
+            reltype = elem.get('Type').split('/')[-1]
+            if self.verbosity >= 2:
+                self.dumpout('Id=%r Type=%r Target=%r', rid, reltype, target)
+            self.relid2reltype[rid] = reltype
+            self.relid2path[rid] = normpath(join('xl/worksheets', target))
+
     def process_comments_stream(self, stream):
         root = ET.parse(stream).getroot()
         author_list = root[0]
@@ -565,25 +596,32 @@ class X12Sheet(X12General):
         if ref:
             # print >> self.logfile, "dimension: ref=%r" % ref
             last_cell_ref = ref.split(':')[-1] # example: "Z99"
-            rowx, colx = cell_name_to_rowx_colx(last_cell_ref)
+            rowx, colx = cell_name_to_rowx_colx(
+                    last_cell_ref, allow_no_col=True)
             self.sheet._dimnrows = rowx + 1
-            self.sheet._dimncols = colx + 1
+            if colx is not None:
+                self.sheet._dimncols = colx + 1
 
     def do_merge_cell(self, elem):
         # The ref attribute should be a cell range like "B1:D5".
         ref = elem.get('ref')
         if ref:
-            first_cell_ref, last_cell_ref = ref.split(':')
+            try:
+                first_cell_ref, last_cell_ref = ref.split(':')
+            except ValueError:
+                # encountered a single cell merge, e.g. "B3"
+                first_cell_ref = ref
+                last_cell_ref = ref
             first_rowx, first_colx = cell_name_to_rowx_colx(first_cell_ref)
             last_rowx, last_colx = cell_name_to_rowx_colx(last_cell_ref)
             self.merged_cells.append((first_rowx, last_rowx + 1,
                                       first_colx, last_colx + 1))
 
     def do_row(self, row_elem):
-    
+
         def bad_child_tag(child_tag):
              raise Exception('cell type %s has unexpected child <%s> at rowx=%r colx=%r' % (cell_type, child_tag, rowx, colx))
- 
+
         row_number = row_elem.get('r')
         if row_number is None: # Yes, it's optional.
             self.rowx += 1
@@ -687,8 +725,6 @@ class X12Sheet(X12General):
             elif cell_type == "b":
                 # b = boolean
                 # <v> child contains "0" or "1"
-                # Maybe the data should be converted with cnv_xsd_boolean;
-                # ECMA standard is silent; Excel 2007 writes 0 or 1
                 for child in cell_elem:
                     child_tag = child.tag
                     if child_tag == V_TAG:
@@ -697,10 +733,11 @@ class X12Sheet(X12General):
                         formula = cooked_text(self, child)
                     else:
                         bad_child_tag(child_tag)
-                self.sheet.put_cell(rowx, colx, XL_CELL_BOOLEAN, int(tvalue), xf_index)
+                self.sheet.put_cell(rowx, colx, XL_CELL_BOOLEAN, cnv_xsd_boolean(tvalue), xf_index)
             elif cell_type == "e":
                 # e = error
                 # <v> child contains e.g. "#REF!"
+                tvalue = '#N/A'
                 for child in cell_elem:
                     child_tag = child.tag
                     if child_tag == V_TAG:
@@ -713,17 +750,23 @@ class X12Sheet(X12General):
                 self.sheet.put_cell(rowx, colx, XL_CELL_ERROR, value, xf_index)
             elif cell_type == "inlineStr":
                 # Not expected in files produced by Excel.
-                # Only possible child is <is>.
                 # It's a way of allowing 3rd party s/w to write text (including rich text) cells
                 # without having to build a shared string table
                 for child in cell_elem:
                     child_tag = child.tag
                     if child_tag == IS_TAG:
                         tvalue = get_text_from_si_or_is(self, child)
+                    elif child_tag == V_TAG:
+                        tvalue = child.text
+                    elif child_tag == F_TAG:
+                        formula = child.text
                     else:
                         bad_child_tag(child_tag)
-                assert tvalue is not None
-                self.sheet.put_cell(rowx, colx, XL_CELL_TEXT, tvalue, xf_index)
+                if not tvalue:
+                    if self.bk.formatting_info:
+                        self.sheet.put_cell(rowx, colx, XL_CELL_BLANK, '', xf_index)
+                else:
+                    self.sheet.put_cell(rowx, colx, XL_CELL_TEXT, tvalue, xf_index)
             else:
                 raise Exception("Unknown cell type %r in rowx=%d colx=%d" % (cell_type, rowx, colx))
 
@@ -793,11 +836,20 @@ def open_workbook_2007_xml(
         heading = "Sheet %r (sheetx=%d) from %r" % (sheet.name, sheetx, fname)
         x12sheet.process_stream(zflo, heading)
         del zflo
-        comments_fname = 'xl/comments%d.xml' % (sheetx + 1)
-        if comments_fname in component_names:
-            comments_stream = zf.open(component_names[comments_fname])
-            x12sheet.process_comments_stream(comments_stream)
-            del comments_stream
+
+        rels_fname = 'xl/worksheets/_rels/%s.rels' % fname.rsplit('/', 1)[-1]
+        if rels_fname in component_names:
+            zfrels = zf.open(rels_fname)
+            x12sheet.process_rels(zfrels)
+            del zfrels
+
+        for relid, reltype in x12sheet.relid2reltype.items():
+            if reltype == 'comments':
+                comments_fname = x12sheet.relid2path.get(relid)
+                if comments_fname and comments_fname in component_names:
+                    comments_stream = zf.open(comments_fname)
+                    x12sheet.process_comments_stream(comments_stream)
+                    del comments_stream
 
         sheet.tidy_dimensions()
 
